@@ -1,4 +1,4 @@
-from itertools import product, cycle, permutations
+from itertools import product, cycle
 import gc
 import sys
 import warnings
@@ -8,10 +8,9 @@ import numpy as np
 from numba import jit, typeof
 from numba.core import types
 from numba.core.compiler import compile_isolated
-from numba.core.errors import (TypingError, LoweringError, NumbaValueError,
-                               NumbaExperimentalFeatureWarning)
+from numba.core.errors import TypingError, NumbaValueError
 from numba.np.numpy_support import as_dtype, numpy_version
-from numba.tests.support import (TestCase, CompilationCache, MemoryLeak,
+from numba.tests.support import (TestCase, CompilationCache,
                                  MemoryLeakMixin, tag, needs_blas)
 import unittest
 
@@ -31,6 +30,9 @@ def np_around_unary(val):
 def np_round_array(arr, decimals, out):
     np.round(arr, decimals, out)
 
+def np_round__array(arr, decimals, out):
+    np.round_(arr, decimals, out)
+
 def np_round_binary(val, decimals):
     return np.round(val, decimals)
 
@@ -366,6 +368,9 @@ class TestArrayMethods(MemoryLeakMixin, TestCase):
     def test_around_array(self):
         self.check_round_array(np_around_array)
 
+    def test_round__array(self):
+        self.check_round_array(np_round__array)
+
     def test_around_bad_array(self):
         for pyfunc in (np_round_unary, np_around_unary):
             cfunc = jit(nopython=True)(pyfunc)
@@ -374,7 +379,7 @@ class TestArrayMethods(MemoryLeakMixin, TestCase):
                 cfunc(None)
 
     def test_around_bad_out(self):
-        for py_func in (np_round_array, np_around_array):
+        for py_func in (np_round_array, np_around_array, np_round__array):
             cfunc = jit(nopython=True)(py_func)
             msg = '.*The argument "out" must be an array if it is provided.*'
             with self.assertRaisesRegex(TypingError, msg):
@@ -785,23 +790,6 @@ class TestArrayMethods(MemoryLeakMixin, TestCase):
     def test_np_where_1(self):
         self.check_nonzero(np_where_1)
 
-    def test_np_where_no_isinstance_warn(self):
-        # TODO: remove this test before Numba 0.58 release
-        # When _isinstance_no_warn has been removed.
-        msg = 'Use of isinstance() detected. This is an experimental feature.'
-        category = NumbaExperimentalFeatureWarning
-        a = np.arange(10)
-        cfunc = jit(nopython=True)(np_where_3)
-
-        with warnings.catch_warnings(record=True) as catch:
-            cfunc(a < 5, a, 10 * a)
-
-            found = False
-            for w in catch:
-                if msg in str(w.message) and w.category == category:
-                    found = True
-            self.assertFalse(found)
-
     def test_np_where_3(self):
         pyfunc = np_where_3
         def fac(N):
