@@ -75,12 +75,18 @@ def array_min(arr):
 def array_min_global(arr):
     return np.min(arr)
 
+def array_amin(arr):
+    return np.amin(arr)
+
 def array_max(arr):
     return arr.max()
 
 def array_max_global(arr):
     return np.max(arr)
 
+def array_amax(arr):
+    return np.amax(arr)
+
 def array_argmin(arr):
     return arr.argmin()
 
@@ -675,11 +681,6 @@ class TestArrayReductions(MemoryLeakMixin, TestCase):
         np.random.shuffle(arr)
         self.assertPreciseEqual(cfunc(arr), pyfunc(arr))
         # Test with a NaT
-        if numpy_version != (1, 21) and 'median' not in pyfunc.__name__:
-            # There's problems with NaT handling in "median" on at least NumPy
-            # 1.21.{3, 4}. See https://github.com/numpy/numpy/issues/20376
-            arr[arr.size // 2] = 'NaT'
-            self.assertPreciseEqual(cfunc(arr), pyfunc(arr))
         if 'median' not in pyfunc.__name__:
             # Test with (val, NaT)^N (and with the random NaT from above)
             # use a loop, there's some weird thing/bug with arr[1::2] = 'NaT'
@@ -1110,6 +1111,7 @@ class TestArrayReductions(MemoryLeakMixin, TestCase):
                            array_all, array_all_global,
                            array_any, array_any_global,
                            array_min, array_min_global,
+                           array_amax, array_amin,
                            array_max, array_max_global,
                            array_nanmax, array_nanmin,
                            array_nansum,
